# A10's Thunder Observability Agent (TOA)
	The TOA is a lightweight autonomous data processing engine that can be externally installed and configured for any Thunder device.
	TOA offers the following capabilities on Application Delivery Controller (ADC):
	
	- Collects, processes and publishes Thunder metrics. 
	  The default data collection frequency is 1 minute. 
	  The metrics can be published on the same platform where the Thunder instance is deployed. 
	  For more information on Thunder metrics, see Thunder Metric Support.
	
	- Collects, processes, and publishes Thunder Syslogs. 
	  The default data collection frequency is 1 minute. 
	  The logs can be published on the same platform where the Thunder instance is deployed. 
	  Additionally, logs can also be sent to any AWS, Azure, or VMware platforms.

    Supported Monitoring Platforms:
	1. AWS.
	2. Azure.
	3. VMware.

	Supported Use Cases:
	1. Monitoring thunder adc metrics or logs or both into AWS Cloudwatch.
	2. Monitoring thunder adc metrics or logs or both into Azure Application Insight and Log Analytics Workspace.
	3. Monitoring thunder adc metrics or logs or both into VMware vRealize Operations and Log Insight.

	Links:
	License				: https://www.a10networks.com/wp-content/uploads/EULA_Thunder_Observability_Agent.pdf
	Open Source (Notice)            : https://github.com/a10networks/thunder-observability-agent/tree/release/v1.0.0/OPEN-SOURCE-DISCLAIMER.pdf
	Documentation		        : https://documentation.a10networks.com
	Repository			: https://github.com/a10networks/thunder-observability-agent/tree/release/v1.0.0
	Example				: https://github.com/a10networks/thunder-observability-agent/tree/release/v1.0.0/examples
	
	
